@@ -13,7 +13,9 @@ class FrequencyConfig(BaseModel):
 
     @property
     def should_publish(self) -> bool:
-        return self.log > 0
+        return self.publish > 0
+
+    websocket: Annotated[int, Field(1, description="Websocket Frequency", ge=0)] = 1
 
 
 class HeartbeatConfig(BaseModel):
